<?php
 /*
  * Plugin name: Easy Background Switcher
  * Version: 1.0
  * Author: WpBrickr
  * Plugin URI: http://easy-background-switcher.wpbrickr.com
  * Author URI: http://www.wpbrickr.com
  * Description: Allows you to change background on any WordPress Theme, you can define special backgrounds per posts/pages.
  */
  
  define('WPB_EBS_OPTION_KEY', 'wpb_ebs_settings');
  
  require_once 'wpb.gui.php';
  
  class wpb_ebs {
    
    
    function init() {
      if (is_admin()) {
        // register admin menu
        add_action('admin_menu', array(__CLASS__, 'add_admin_menus'));
        // enqueue scripts in admin
        add_action('admin_enqueue_scripts', array(__CLASS__, 'admin_enqueue_scripts'));
        // add bg change meta box
        add_action('add_meta_boxes', array(__CLASS__, 'register_custom_meta'));
        // add background picker form
        add_action('admin_footer', array(__CLASS__, 'form'));
        // save meta data
        add_action('save_post', array(__CLASS__, 'save_meta_data'));
        // add links
        add_action('plugin_action_links_' . basename(dirname(__FILE__)) . '/' . basename(__FILE__), array(__CLASS__, 'plugin_action_links'));
      } else {
        // add css style to the page
        add_action('wp_head', array(__CLASS__, 'apply_background'));
      }
      
      add_action('wp_ajax_wpb_ebs_change_bg', array(__CLASS__, 'ajax_change_bg'));
      add_action('wp_ajax_wpb_ebs_remove_post_bg', array(__CLASS__, 'ajax_remove_post_bg'));
    } // init
    
    
    // add settings link to plugins page
    function plugin_action_links($links) {
      $settings_link = '<a href="themes.php?page=wpb-ebs" title="Easy Background Switcher Settings">Settings</a>';
      $doc_link = '<a href="' . plugins_url('/documentation/index.html', __FILE__) . '" target="_blank" title="Easy Background Switcher Documentation">Documentation</a>';
      array_unshift($links, $doc_link);
      array_unshift($links, $settings_link);

      return $links;
    } // plugin_action_links
    
    
    function form() {
        $bg = get_option(WPB_EBS_OPTION_KEY);
        
        echo '<form id="wpb-ebs-form" style="display:none; padding:10px;">';

        // Background
        echo '<div style="overflow-y:scroll;height:450px;">';
        echo '<p>';
        echo '<span>Select background you wish to use.</span>';
        echo wpb_ebs_gui::update_backgrounds();
        echo '<span>Select background you wish to use.</span>';
        echo '</p>';
        echo '</div>';

        echo '<div class="clear"></div>';
        echo '<p>';
        echo '<input type="submit" class="button-primary" name="wpb-epgf-submit" id="wpb-epgf-submit" value="Save" />&nbsp;&nbsp;&nbsp;';
        echo '<input type="button" class="button-secondary" id="wpb-epgf-cancel" value="Cancel" name="wpb-epgf-cancel" />';
        echo '</p>';

        echo '</table>';
        echo '</form>';
    } // form
    
    
    function register_custom_meta() {
      $post_types = get_post_types();      
      unset($post_types['attachment'], $post_types['revision'], $post_types['nav_menu_item']);
      foreach ($post_types as $k => $v) {
        add_meta_box('wpb-ebs-settings', 'Background Settings', array(__CLASS__, 'admin_render_settings'), $k, 'side', 'high');
      }
    } // register_custom_meta
    
    
    function admin_render_settings() {
      global $post;
      $bg_setup = get_post_meta($post->ID, 'wpb-ebs-settings', true);
      
      if (!isset($bg_setup['bg']) || $bg_setup['bg'] == '') {
        echo '<div class="wpb-ebs-no-img">';
        echo 'This post currently has no active background image! ';
        echo '<a href="#" id="wpb-ebs-display-form-link">Click here to add it!</a>';
        echo '</div>';
        
        // Background selected
        echo '<div align="center" class="wpb-ebs-img-post-container" style="display:none;">';
        echo '<div class="wpb-ebs-img-post" data-bg="" style=""></div>';
        echo '<input type="hidden" name="wpb-ebs-settings[bg]" id="wpb-ebs-settings-bg" value="" />';
        echo '<a href="#" class="wpb-ebs-settings-bg-remove">Remove Background</a>';
        echo '</div>';
      } else {
        echo '<div class="wpb-ebs-no-img" style="display:none;">';
        echo 'This post currently has no active background image! ';
        echo '<a href="#" id="wpb-ebs-display-form-link">Click here to add it!</a>';
        echo '</div>';
        
        // Background selected
        echo '<div align="center" class="wpb-ebs-img-post-container" style="display:block;">';
        echo '<div class="wpb-ebs-img-post" data-bg="' . $bg_setup['bg'] . '" style="display:block;background:url(\'' . $bg_setup['bg'] . '\') top left repeat;"></div>';
        echo '<input type="hidden" name="wpb-ebs-settings[bg]" id="wpb-ebs-settings-bg" value="' . $bg_setup['bg'] . '" />';
        echo '<input type="hidden" name="wpb-ebs-settings[post_id]" id="wpb-ebs-settings-post-id" value="' . $post->ID . '" />';
        echo '<a href="#" class="wpb-ebs-settings-bg-remove">Remove Background</a>';
        echo '</div>';
      }
      
    } // admin_render_settings
    
    
    function ajax_change_bg() {
      $bg = trim($_POST['bg-url']);
      if (update_option(WPB_EBS_OPTION_KEY, $bg)) {
        echo 'ok';
      }
      die();
    } // ajax_change_bg
    
    
    function ajax_remove_post_bg() {
      $post = trim($_POST['post_id']);
      if (delete_post_meta($post, 'wpb-ebs-settings')) {
        echo 'ok';
      }
      die();
    } // ajax_remove_post_bg
    
    
    function add_admin_menus() {
      add_theme_page('Background Switcher', 'Background Switcher', 'manage_options', 'wpb-ebs', array('wpb_ebs_gui', 'settings'));
    } // add_admin_menus
   
   
    function admin_enqueue_scripts() {
      $screen = get_current_screen();
     
      if ($screen->id == 'appearance_page_wpb-ebs' || $screen->base == 'post') {
        wp_enqueue_script('wpb-ebs-backend-jquery', plugins_url('js/wpb.gui.js', __FILE__), array('jquery'), '1.0', true);
        wp_enqueue_style('wpb-ebs-backend-style', plugins_url('css/style.css', __FILE__), array(), '1.0');
      }
      
      if ($screen->base == 'post') {
        wp_enqueue_style('wp-jquery-ui-dialog');
        wp_enqueue_script('wp-jquery-ui-dialog');
      }
    } // admin_enqueue_scripts
   
   
    function apply_background() {
      global $post;
      $global_bg = get_option(WPB_EBS_OPTION_KEY);
      $post_bg   = get_post_meta($post->ID, 'wpb-ebs-settings', true);
      
      if ($post_bg && $post_bg['bg'] != '') {
        echo '<style type="text/css">';
        echo 'body {
               background-image:url("' . $post_bg['bg'] . '");
               background-position:top left;
               background-repeat:repeat;
              }';
        echo '</style>';
      } else {
        echo '<style type="text/css">';
        echo 'body {
               background-image:url("' . $global_bg . '");
               background-position:top left;
               background-repeat:repeat;
              }';
        echo '</style>';
      }
    } // apply_background
    
    
    function save_meta_data() {
      global $post;
      $settings = $_POST['wpb-ebs-settings'];
      
      // Clean before saving
      $settings['bg'] = str_replace('background:url(\\\'', '', $settings['bg']);
      $settings['bg'] = str_replace('\\\') top left repeat;', '', $settings['bg']);
      
      update_post_meta($post->ID, 'wpb-ebs-settings', $settings);
    } // save_meta_data
    
    
  } // wpb_ebs
  
  add_action('init', array('wpb_ebs', 'init'));